"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.describeFullCompat = exports.describeLoaderCompat = exports.describeNoCompat = void 0;
const test_utils_1 = require("@fluidframework/test-utils");
const compatConfig_1 = require("./compatConfig");
const compatOptions_1 = require("./compatOptions");
const compatUtils_1 = require("./compatUtils");
/*
 * Mocha Utils for test to generate the compat variants.
 */
function createCompatSuite(tests, compatFilter) {
    return function () {
        let configs = compatConfig_1.configList.value;
        if (compatFilter !== undefined) {
            configs = configs.filter((value) => compatFilter.includes(value.kind));
        }
        for (const config of configs) {
            describe(config.name, function () {
                let provider;
                let resetAfterEach;
                before(async function () {
                    provider = await (0, compatUtils_1.getVersionedTestObjectProvider)(compatOptions_1.baseVersion, config.loader, {
                        type: compatOptions_1.driver,
                        version: config.driver,
                        config: {
                            r11s: { r11sEndpointName: compatOptions_1.r11sEndpointName },
                            odsp: { tenantIndex: compatOptions_1.tenantIndex },
                        },
                    }, config.containerRuntime, config.dataRuntime);
                    Object.defineProperty(this, "__fluidTestProvider", { get: () => provider });
                });
                tests.bind(this)((options) => {
                    var _a;
                    resetAfterEach = (_a = options === null || options === void 0 ? void 0 : options.resetAfterEach) !== null && _a !== void 0 ? _a : true;
                    if ((options === null || options === void 0 ? void 0 : options.syncSummarizer) === true) {
                        provider.resetLoaderContainerTracker(true /* syncSummarizerClients */);
                    }
                    return provider;
                });
                afterEach(function (done) {
                    var _a;
                    const logErrors = (0, test_utils_1.getUnexpectedLogErrorException)(provider.logger);
                    // if the test failed for another reason
                    // then we don't need to check errors
                    // and fail the after each as well
                    if (((_a = this.currentTest) === null || _a === void 0 ? void 0 : _a.state) === "passed") {
                        done(logErrors);
                    }
                    else {
                        done();
                    }
                    if (resetAfterEach) {
                        provider.reset();
                    }
                });
            });
        }
    };
}
function createCompatDescribe(compatFilter) {
    const d = (name, tests) => describe(name, createCompatSuite(tests, compatFilter));
    d.skip = (name, tests) => describe.skip(name, createCompatSuite(tests, compatFilter));
    d.only = (name, tests) => describe.only(name, createCompatSuite(tests, compatFilter));
    d.noCompat = (name, tests) => describe(name, createCompatSuite(tests, [compatOptions_1.CompatKind.None]));
    return d;
}
exports.describeNoCompat = createCompatDescribe([compatOptions_1.CompatKind.None]);
exports.describeLoaderCompat = createCompatDescribe([compatOptions_1.CompatKind.None, compatOptions_1.CompatKind.Loader]);
exports.describeFullCompat = createCompatDescribe();
//# sourceMappingURL=describeCompat.js.map