"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.itExpects = void 0;
const test_utils_1 = require("@fluidframework/test-utils");
function createExpectsTest(orderedExpectedEvents, test) {
    return async function () {
        var _a, _b;
        const provider = this.__fluidTestProvider;
        if (provider === undefined) {
            throw new Error("Expected __fluidTestProvider on this");
        }
        const orderedEvents = Array.isArray(orderedExpectedEvents)
            ? orderedExpectedEvents
            : (_a = orderedExpectedEvents[provider.driver.type]) !== null && _a !== void 0 ? _a : [];
        try {
            provider.logger.registerExpectedEvent(...orderedEvents);
            await test.bind(this)();
        }
        catch (error) {
            // only use TestException if the event is provided.
            // it must be last, as the events are ordered, so all other events must come first
            if (((_b = orderedEvents[orderedEvents.length - 1]) === null || _b === void 0 ? void 0 : _b.eventName) === "TestException") {
                provider.logger.sendErrorEvent({ eventName: "TestException" }, error);
            }
            else {
                throw error;
            }
        }
        const err = (0, test_utils_1.getUnexpectedLogErrorException)(provider.logger);
        if (err !== undefined) {
            throw err;
        }
    };
}
/**
 * Similar to mocha's it function, but allow specifying expected events.
 * That must occur during the execution of the test.
 */
const itExpects = (name, orderedExpectedEvents, test) => it(name, createExpectsTest(orderedExpectedEvents, test));
exports.itExpects = itExpects;
exports.itExpects.only =
    (name, orderedExpectedEvents, test) => it.only(name, createExpectsTest(orderedExpectedEvents, test));
exports.itExpects.skip =
    (name, orderedExpectedEvents, test) => it.skip(name, createExpectsTest(orderedExpectedEvents, test));
//# sourceMappingURL=itExpects.js.map